# LabPaper Documentation

```{toctree}
:maxdepth: 2
:caption: Contents

README
exporters
filters
preprocessors
templates
texmf
```

```{include} ../README.md
:relative-docs: docs
:start-after: "# LabPaper"
``` 